@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'				=> 'Tijdzone voor gasten',
 	'SYSTEM_TIMEZONE_EXPLAIN'		=> 'Tijdzone die wordt weergegeven aan gebruikers die niet ingelogd zijn(gasten, bots). Ingelogde gebruikers stellen hun tijdzone in bij de registratie en kunnen dit aanpassen in hun gebruikerspaneel.',
 	'WARNINGS_EXPIRE'				=> 'Duur van de waarschuwing',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Aantal dagen waarna een waarschuwing automatisch voor de gebruiker vervalt.',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Aantal dagen waarna een waarschuwing automatisch voor de gebruiker vervalt. Stel deze waarde in op 0 om waarschuwingen permanent te laten staan.',
 ));
 
 // Board Features
@@ -174,7 +174,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'					=> 'Maximaal aantal links per bericht',
 	'MAX_POST_URLS_EXPLAIN'			=> 'Maximaal aantal URL’s in een bericht. Stel in op 0 voor onbeperkt.',
 	'MIN_CHAR_LIMIT'				=> 'Minimaal aantal tekens per (privé)bericht',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Het minimale aantal tekens dat vereist is in een (privé)bericht.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Het minimale aantal tekens dat vereist is in een (privé)bericht. De minimale waarde is 1 voor deze instelling',
 	'POSTING'						=> 'Berichtenplaatsing',
 	'POSTS_PER_PAGE'				=> 'Berichten per pagina',
 	'QUOTE_DEPTH_LIMIT'				=> 'Maximaal aantal geneste citaten per bericht',
