@@ -326,6 +326,16 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'	=> 'Databaseserver',
 	'DATABASE_SIZE'			=> 'Databasegrootte',
 
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'De overbelasting functie is niet juist geconfigureerd',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> moet op 0 of 4 worden ingesteld. Je kunt de huidige waarde controleren op de <samp>PHP informatie</samp> pagina.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'De transparante karakter encoding is niet juist geconfigureerd',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> must be set to 0 worden ingesteld. Je kunt de huidige waarde controleren op de <samp>PHP informatie</samp> pagina.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'De HTTP input karakter conversie is niet juist geconfigureerd',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> must be set to <samp>pass</samp> worden ingesteld. Je kunt de huidige waarde controleren op de <samp>PHP informatie</samp> pagina.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'De HTTP output karakter conversie is niet juist geconfigureerd',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> moet op <samp>pass</samp> worden ingesteld. Je kunt de huidige waarde controleren op de <samp>PHP informatie</samp> pagina.',
+
 	'FILES_PER_DAY'		=> 'Bijlagen per dag',
 	'FORUM_STATS'		=> 'Forumstatistieken',
 
