@@ -4,7 +4,7 @@
 * common [Dutch]
 *
 * @package language
-* @version $Id: common.php,v 1.0.0 2006/08/12 13:55:01 naderman Exp $
+* @version $Id$
 * @copyright (c) 2005 phpBB Group modified by phpBB.nl (vertaalteam@phpbb.nl) in 2007
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
@@ -43,7 +43,7 @@ $lang = array_merge($lang, array(
 	'TRANSLATION_INFO'	=> '<a href="http://www.phpbb.nl">phpBB.nl Vertaling</a>', // Copyright mag verwijderd worden
 	'DIRECTION'			=> 'ltr',
 	'DATE_FORMAT'		=> '|d M Y|',	// 01 Jan 2007 (with Relative days enabled)
-	'USER_LANG'			=> 'nl-nl',
+	'USER_LANG'			=> 'nl',
 
 	'1_DAY'			=> '1 dag',
 	'1_MONTH'		=> '1 maand',
@@ -54,7 +54,7 @@ $lang = array_merge($lang, array(
 	'7_DAYS'		=> '7 dagen',
 
 	'ACCOUNT_ALREADY_ACTIVATED'		=> 'Je account is reeds geactiveerd.',
-	'ACCOUNT_DEACTIVATED'			=> 'Je account is gedeactiveerd en kan alleen door een beheerder opnieuw worden geactiveerd.',
+	'ACCOUNT_DEACTIVATED'			=> 'Je account is handmatig gedeactiveerd en kan alleen door een beheerder opnieuw worden geactiveerd.',
 	'ACCOUNT_NOT_ACTIVATED'			=> 'Je account is nog niet geactiveerd.',
 	'ACP'							=> 'Beheerderspaneel',
 	'ACTIVE'						=> 'Actief',
@@ -153,9 +153,9 @@ $lang = array_merge($lang, array(
 	'DOWNLOAD_COUNT'		=> '%d keer gedownload',
 	'DOWNLOAD_COUNTS'		=> '%d keer gedownload',
 	'DOWNLOAD_COUNT_NONE'	=> 'Nog niet gedownload',
-	'VIEWED_COUNT' 			=> '%d keer bekeken',
-	'VIEWED_COUNTS' 		=> '%d keer bekeken',
-	'VIEWED_COUNT_NONE' 	=> 'Nog niet bekeken',
+	'VIEWED_COUNT'			=> '%d keer bekeken',
+	'VIEWED_COUNTS'			=> '%d keer bekeken',
+	'VIEWED_COUNT_NONE'		=> 'Nog niet bekeken',
 
 	'EDIT_POST'							=> 'Wijzig bericht',
 	'EMAIL'								=> 'E-mail', // Short form for EMAIL_ADDRESS
@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Je moet een onderwerp opgeven bij het plaatsen van een nieuw bericht.',
 	'ENABLED'							=> 'Ingeschakeld',
 	'ENCLOSURE'							=> 'Bijgevoegd',
+	'ENTER_USERNAME'					=> 'Vul gebruikersnaam in',
 	'ERR_CHANGING_DIRECTORY'			=> 'De map kon niet worden gewijzigd.',
 	'ERR_CONNECTING_SERVER'				=> 'Er ging iets fout bij het verbinden met de server.',
 	'ERR_JAB_AUTH'						=> 'Het aanmelden op de Jabber server is mislukt.',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'Klik hier om de forumregels te lezen.',
 	'FROM'					=> 'van',
 	'FSOCK_DISABLED'		=> 'De actie kon niet worden uitgevoerd omdat de fsock-functies uitgeschakeld zijn, of omdat de betreffende server niet werd gevonden.',
+	'FSOCK_TIMEOUT'			=> 'Er is een time-out opgetreden tijdens het lezen van de netwerk stream.',
 
 	'FTP_FSOCK_HOST'				=> 'FTP-host',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'De FTP-server waar je jouw website naar uploadt.',
@@ -281,11 +283,11 @@ $lang = array_merge($lang, array(
 	'IP'						=> 'IP',
 	'IP_BLACKLISTED'			=> 'Jouw IP %1$s is geblokkeerd omdat deze op de zwarte lijst staat. Voor meer informatie zie %2$s.',
 
-	'JABBER'		=> 'Jabber',
-	'JOINED'		=> 'Geregistreerd',
-	'JUMP_PAGE'		=> 'Geef het paginanummer op van waar je naartoe wilt gaan.',
-	'JUMP_TO'		=> 'Ga naar',
-	'JUMP_TO_PAGE'	=> 'Klik om naar de pagina te gaan…',
+	'JABBER'				=> 'Jabber',
+	'JOINED'				=> 'Geregistreerd',
+	'JUMP_PAGE'				=> 'Geef het paginanummer op van waar je naartoe wilt gaan.',
+	'JUMP_TO'				=> 'Ga naar',
+	'JUMP_TO_PAGE'			=> 'Klik om naar de pagina te gaan…',
 
 	'KB'					=> 'KB',
 	'KIB'					=> 'KiB',
@@ -652,6 +654,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> ongelezen berichten',
 	'UNREAD_POST'			=> 'Ongelezen bericht',
 	'UNREAD_POSTS'			=> 'Ongelezen berichten',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Weet je zeker dat je geen abonnement meer wilt op dit forum?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Weet je zeker dat je geen abonnement meer wilt op forum “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Weet je zeker dat je geen abonnement meer wilt op dit onderwerp?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Weet je zeker dat je geen abonnement meer wilt op onderwerp “%s”?',
 	'UNWATCHED_FORUMS'			=> 'Je bent niet langer op de aangegeven forums geabonneerd.',
 	'UNWATCHED_TOPICS'			=> 'Je bent niet langer op de geselecteerde onderwerpen geabonneerd.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Je bent niet langer op de geselecteerde items geabonneerd.',
@@ -700,6 +706,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Waarschuwingen',
 	'WARN_USER'			=> 'Waarschuw gebruiker',
+	'WATCH_FORUM_CONFIRM'	=> 'Weet je zeker dat je wilt abboneren op dit forum?',
+	'WATCH_FORUM_DETAILED'	=> 'Weet je zeker dat je wilt abboneren op forum “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Weet je zeker dat je wilt abboneren op dit onderwerp?',
+	'WATCH_TOPIC_DETAILED'	=> 'Weet je zeker dat je wilt abboneren op onderwerp “%s”?',
 	'WELCOME_SUBJECT'	=> 'Welkom bij de %s forums',
 	'WEBSITE'			=> 'Website',
 	'WHOIS'				=> 'Whois',
